"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import admin_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ModerationVisibility:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModerationVisibilityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModerationVisibility.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODERATION_VISIBILITY_UNSPECIFIED: _ModerationVisibility.ValueType  # 0
    MODERATION_VISIBILITY_HIDDEN: _ModerationVisibility.ValueType  # 1
    """Only visible to moderators"""
    MODERATION_VISIBILITY_SHADOWED: _ModerationVisibility.ValueType  # 2
    """Visible to author & recipient, not in listings"""
    MODERATION_VISIBILITY_VISIBLE: _ModerationVisibility.ValueType  # 3
    """Fully visible AND appears in listings"""
    MODERATION_VISIBILITY_UNLISTED: _ModerationVisibility.ValueType  # 4
    """Visible at direct links, but not in listings"""

class ModerationVisibility(_ModerationVisibility, metaclass=_ModerationVisibilityEnumTypeWrapper): ...

MODERATION_VISIBILITY_UNSPECIFIED: ModerationVisibility.ValueType  # 0
MODERATION_VISIBILITY_HIDDEN: ModerationVisibility.ValueType  # 1
"""Only visible to moderators"""
MODERATION_VISIBILITY_SHADOWED: ModerationVisibility.ValueType  # 2
"""Visible to author & recipient, not in listings"""
MODERATION_VISIBILITY_VISIBLE: ModerationVisibility.ValueType  # 3
"""Fully visible AND appears in listings"""
MODERATION_VISIBILITY_UNLISTED: ModerationVisibility.ValueType  # 4
"""Visible at direct links, but not in listings"""
Global___ModerationVisibility: typing_extensions.TypeAlias = ModerationVisibility

class _ModerationTrigger:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModerationTriggerEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModerationTrigger.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODERATION_TRIGGER_UNSPECIFIED: _ModerationTrigger.ValueType  # 0
    MODERATION_TRIGGER_INITIAL_REVIEW: _ModerationTrigger.ValueType  # 1
    MODERATION_TRIGGER_USER_FLAG: _ModerationTrigger.ValueType  # 2
    MODERATION_TRIGGER_MACHINE_FLAG: _ModerationTrigger.ValueType  # 3
    MODERATION_TRIGGER_MODERATOR_REVIEW: _ModerationTrigger.ValueType  # 4

class ModerationTrigger(_ModerationTrigger, metaclass=_ModerationTriggerEnumTypeWrapper): ...

MODERATION_TRIGGER_UNSPECIFIED: ModerationTrigger.ValueType  # 0
MODERATION_TRIGGER_INITIAL_REVIEW: ModerationTrigger.ValueType  # 1
MODERATION_TRIGGER_USER_FLAG: ModerationTrigger.ValueType  # 2
MODERATION_TRIGGER_MACHINE_FLAG: ModerationTrigger.ValueType  # 3
MODERATION_TRIGGER_MODERATOR_REVIEW: ModerationTrigger.ValueType  # 4
Global___ModerationTrigger: typing_extensions.TypeAlias = ModerationTrigger

class _ModerationAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModerationActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModerationAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODERATION_ACTION_UNSPECIFIED: _ModerationAction.ValueType  # 0
    MODERATION_ACTION_CREATE: _ModerationAction.ValueType  # 1
    MODERATION_ACTION_APPROVE: _ModerationAction.ValueType  # 2
    MODERATION_ACTION_HIDE: _ModerationAction.ValueType  # 3
    MODERATION_ACTION_FLAG: _ModerationAction.ValueType  # 4
    MODERATION_ACTION_UNFLAG: _ModerationAction.ValueType  # 5
    MODERATION_ACTION_BULK_SET_VISIBILITY: _ModerationAction.ValueType  # 6
    MODERATION_ACTION_SET_PRIORITY: _ModerationAction.ValueType  # 7

class ModerationAction(_ModerationAction, metaclass=_ModerationActionEnumTypeWrapper): ...

MODERATION_ACTION_UNSPECIFIED: ModerationAction.ValueType  # 0
MODERATION_ACTION_CREATE: ModerationAction.ValueType  # 1
MODERATION_ACTION_APPROVE: ModerationAction.ValueType  # 2
MODERATION_ACTION_HIDE: ModerationAction.ValueType  # 3
MODERATION_ACTION_FLAG: ModerationAction.ValueType  # 4
MODERATION_ACTION_UNFLAG: ModerationAction.ValueType  # 5
MODERATION_ACTION_BULK_SET_VISIBILITY: ModerationAction.ValueType  # 6
MODERATION_ACTION_SET_PRIORITY: ModerationAction.ValueType  # 7
Global___ModerationAction: typing_extensions.TypeAlias = ModerationAction

class _ModerationObjectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ModerationObjectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ModerationObjectType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    MODERATION_OBJECT_TYPE_UNSPECIFIED: _ModerationObjectType.ValueType  # 0
    MODERATION_OBJECT_TYPE_HOST_REQUEST: _ModerationObjectType.ValueType  # 1
    MODERATION_OBJECT_TYPE_GROUP_CHAT: _ModerationObjectType.ValueType  # 2
    MODERATION_OBJECT_TYPE_FRIEND_REQUEST: _ModerationObjectType.ValueType  # 3
    MODERATION_OBJECT_TYPE_EVENT_OCCURRENCE: _ModerationObjectType.ValueType  # 4
    MODERATION_OBJECT_TYPE_COMMENT: _ModerationObjectType.ValueType  # 5
    MODERATION_OBJECT_TYPE_REPLY: _ModerationObjectType.ValueType  # 6
    MODERATION_OBJECT_TYPE_DISCUSSION: _ModerationObjectType.ValueType  # 7
    MODERATION_OBJECT_TYPE_REFERENCE: _ModerationObjectType.ValueType  # 8

class ModerationObjectType(_ModerationObjectType, metaclass=_ModerationObjectTypeEnumTypeWrapper): ...

MODERATION_OBJECT_TYPE_UNSPECIFIED: ModerationObjectType.ValueType  # 0
MODERATION_OBJECT_TYPE_HOST_REQUEST: ModerationObjectType.ValueType  # 1
MODERATION_OBJECT_TYPE_GROUP_CHAT: ModerationObjectType.ValueType  # 2
MODERATION_OBJECT_TYPE_FRIEND_REQUEST: ModerationObjectType.ValueType  # 3
MODERATION_OBJECT_TYPE_EVENT_OCCURRENCE: ModerationObjectType.ValueType  # 4
MODERATION_OBJECT_TYPE_COMMENT: ModerationObjectType.ValueType  # 5
MODERATION_OBJECT_TYPE_REPLY: ModerationObjectType.ValueType  # 6
MODERATION_OBJECT_TYPE_DISCUSSION: ModerationObjectType.ValueType  # 7
MODERATION_OBJECT_TYPE_REFERENCE: ModerationObjectType.ValueType  # 8
Global___ModerationObjectType: typing_extensions.TypeAlias = ModerationObjectType

@typing.final
class ModerationStateInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATE_ID_FIELD_NUMBER: builtins.int
    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UPDATED_FIELD_NUMBER: builtins.int
    AUTHOR_USER_ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    moderation_state_id: builtins.int
    object_type: Global___ModerationObjectType.ValueType
    object_id: builtins.int
    visibility: Global___ModerationVisibility.ValueType
    author_user_id: builtins.int
    content: builtins.str
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def author(self) -> admin_pb2.UserDetails: ...
    def __init__(
        self,
        *,
        moderation_state_id: builtins.int | None = ...,
        object_type: Global___ModerationObjectType.ValueType | None = ...,
        object_id: builtins.int | None = ...,
        visibility: Global___ModerationVisibility.ValueType | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        author_user_id: builtins.int | None = ...,
        content: builtins.str | None = ...,
        author: admin_pb2.UserDetails | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["author", b"author", "created", b"created", "updated", b"updated"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["author", b"author", "author_user_id", b"author_user_id", "content", b"content", "created", b"created", "moderation_state_id", b"moderation_state_id", "object_id", b"object_id", "object_type", b"object_type", "updated", b"updated", "visibility", b"visibility"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ModerationStateInfo: typing_extensions.TypeAlias = ModerationStateInfo

@typing.final
class ModerationQueueItemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ITEM_ID_FIELD_NUMBER: builtins.int
    MODERATION_STATE_ID_FIELD_NUMBER: builtins.int
    TIME_CREATED_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    IS_RESOLVED_FIELD_NUMBER: builtins.int
    RESOLVED_BY_LOG_ID_FIELD_NUMBER: builtins.int
    MODERATION_STATE_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    queue_item_id: builtins.int
    moderation_state_id: builtins.int
    trigger: Global___ModerationTrigger.ValueType
    reason: builtins.str
    is_resolved: builtins.bool
    resolved_by_log_id: builtins.int
    priority: builtins.int
    @property
    def time_created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def moderation_state(self) -> Global___ModerationStateInfo: ...
    def __init__(
        self,
        *,
        queue_item_id: builtins.int | None = ...,
        moderation_state_id: builtins.int | None = ...,
        time_created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        trigger: Global___ModerationTrigger.ValueType | None = ...,
        reason: builtins.str | None = ...,
        is_resolved: builtins.bool | None = ...,
        resolved_by_log_id: builtins.int | None = ...,
        moderation_state: Global___ModerationStateInfo | None = ...,
        priority: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state", "time_created", b"time_created"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["is_resolved", b"is_resolved", "moderation_state", b"moderation_state", "moderation_state_id", b"moderation_state_id", "priority", b"priority", "queue_item_id", b"queue_item_id", "reason", b"reason", "resolved_by_log_id", b"resolved_by_log_id", "time_created", b"time_created", "trigger", b"trigger"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ModerationQueueItemInfo: typing_extensions.TypeAlias = ModerationQueueItemInfo

@typing.final
class ModerationLogEntryInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_ENTRY_ID_FIELD_NUMBER: builtins.int
    MODERATION_STATE_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    MODERATOR_USER_ID_FIELD_NUMBER: builtins.int
    NEW_VISIBILITY_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    NEW_PRIORITY_FIELD_NUMBER: builtins.int
    QUEUE_ITEM_ID_FIELD_NUMBER: builtins.int
    log_entry_id: builtins.int
    moderation_state_id: builtins.int
    action: Global___ModerationAction.ValueType
    moderator_user_id: builtins.int
    new_visibility: Global___ModerationVisibility.ValueType
    reason: builtins.str
    new_priority: builtins.int
    queue_item_id: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        log_entry_id: builtins.int | None = ...,
        moderation_state_id: builtins.int | None = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        action: Global___ModerationAction.ValueType | None = ...,
        moderator_user_id: builtins.int | None = ...,
        new_visibility: Global___ModerationVisibility.ValueType | None = ...,
        reason: builtins.str | None = ...,
        new_priority: builtins.int | None = ...,
        queue_item_id: builtins.int | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["time", b"time"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["action", b"action", "log_entry_id", b"log_entry_id", "moderation_state_id", b"moderation_state_id", "moderator_user_id", b"moderator_user_id", "new_priority", b"new_priority", "new_visibility", b"new_visibility", "queue_item_id", b"queue_item_id", "reason", b"reason", "time", b"time"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ModerationLogEntryInfo: typing_extensions.TypeAlias = ModerationLogEntryInfo

@typing.final
class GetModerationQueueReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIGGERS_FIELD_NUMBER: builtins.int
    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    UNRESOLVED_ONLY_FIELD_NUMBER: builtins.int
    CREATED_BEFORE_FIELD_NUMBER: builtins.int
    CREATED_AFTER_FIELD_NUMBER: builtins.int
    ITEM_AUTHOR_USER_ID_FIELD_NUMBER: builtins.int
    PRIORITY_MIN_FIELD_NUMBER: builtins.int
    PRIORITY_MAX_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    NEWEST_FIRST_FIELD_NUMBER: builtins.int
    object_type: Global___ModerationObjectType.ValueType
    """Filter by object type (optional)"""
    unresolved_only: builtins.bool
    """Only show unresolved items"""
    item_author_user_id: builtins.int
    """Filter by content author (optional)"""
    priority_min: builtins.int
    """Filter to items with priority >= this value (optional)"""
    priority_max: builtins.int
    """Filter to items with priority <= this value (optional)"""
    page_size: builtins.int
    """Pagination"""
    page_token: builtins.str
    newest_first: builtins.bool
    """Order by newest first (default: false = oldest first)"""
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[Global___ModerationTrigger.ValueType]:
        """Filter by trigger type (optional)"""

    @property
    def created_before(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Filter to items created before this time (optional)"""

    @property
    def created_after(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Filter to items created after this time (optional)"""

    def __init__(
        self,
        *,
        triggers: collections.abc.Iterable[Global___ModerationTrigger.ValueType] | None = ...,
        object_type: Global___ModerationObjectType.ValueType | None = ...,
        unresolved_only: builtins.bool | None = ...,
        created_before: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_after: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        item_author_user_id: builtins.int | None = ...,
        priority_min: builtins.int | None = ...,
        priority_max: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        newest_first: builtins.bool | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["_priority_max", b"_priority_max", "_priority_min", b"_priority_min", "created_after", b"created_after", "created_before", b"created_before", "priority_max", b"priority_max", "priority_min", b"priority_min"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["_priority_max", b"_priority_max", "_priority_min", b"_priority_min", "created_after", b"created_after", "created_before", b"created_before", "item_author_user_id", b"item_author_user_id", "newest_first", b"newest_first", "object_type", b"object_type", "page_size", b"page_size", "page_token", b"page_token", "priority_max", b"priority_max", "priority_min", b"priority_min", "triggers", b"triggers", "unresolved_only", b"unresolved_only"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__priority_max: typing_extensions.TypeAlias = typing.Literal["priority_max"]
    _WhichOneofArgType__priority_max: typing_extensions.TypeAlias = typing.Literal["_priority_max", b"_priority_max"]
    _WhichOneofReturnType__priority_min: typing_extensions.TypeAlias = typing.Literal["priority_min"]
    _WhichOneofArgType__priority_min: typing_extensions.TypeAlias = typing.Literal["_priority_min", b"_priority_min"]
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__priority_max) -> _WhichOneofReturnType__priority_max | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__priority_min) -> _WhichOneofReturnType__priority_min | None: ...

Global___GetModerationQueueReq: typing_extensions.TypeAlias = GetModerationQueueReq

@typing.final
class GetModerationQueueRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ITEMS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def queue_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ModerationQueueItemInfo]: ...
    def __init__(
        self,
        *,
        queue_items: collections.abc.Iterable[Global___ModerationQueueItemInfo] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["next_page_token", b"next_page_token", "queue_items", b"queue_items"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetModerationQueueRes: typing_extensions.TypeAlias = GetModerationQueueRes

@typing.final
class GetModerationStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_TYPE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    object_type: Global___ModerationObjectType.ValueType
    object_id: builtins.int
    def __init__(
        self,
        *,
        object_type: Global___ModerationObjectType.ValueType | None = ...,
        object_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["object_id", b"object_id", "object_type", b"object_type"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetModerationStateReq: typing_extensions.TypeAlias = GetModerationStateReq

@typing.final
class GetModerationStateRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATE_FIELD_NUMBER: builtins.int
    @property
    def moderation_state(self) -> Global___ModerationStateInfo: ...
    def __init__(
        self,
        *,
        moderation_state: Global___ModerationStateInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetModerationStateRes: typing_extensions.TypeAlias = GetModerationStateRes

@typing.final
class GetModerationLogReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATE_ID_FIELD_NUMBER: builtins.int
    moderation_state_id: builtins.int
    def __init__(
        self,
        *,
        moderation_state_id: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state_id", b"moderation_state_id"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetModerationLogReq: typing_extensions.TypeAlias = GetModerationLogReq

@typing.final
class GetModerationLogRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOG_ENTRIES_FIELD_NUMBER: builtins.int
    MODERATION_STATE_FIELD_NUMBER: builtins.int
    @property
    def log_entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ModerationLogEntryInfo]: ...
    @property
    def moderation_state(self) -> Global___ModerationStateInfo: ...
    def __init__(
        self,
        *,
        log_entries: collections.abc.Iterable[Global___ModerationLogEntryInfo] | None = ...,
        moderation_state: Global___ModerationStateInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["log_entries", b"log_entries", "moderation_state", b"moderation_state"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetModerationLogRes: typing_extensions.TypeAlias = GetModerationLogRes

@typing.final
class ModerateContentReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATE_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    QUEUE_ITEM_ID_FIELD_NUMBER: builtins.int
    TRIGGER_FIELD_NUMBER: builtins.int
    SUPERSEDE_QUEUE_ITEM_ID_FIELD_NUMBER: builtins.int
    CLEAR_FLAGS_FIELD_NUMBER: builtins.int
    moderation_state_id: builtins.int
    action: Global___ModerationAction.ValueType
    """Required"""
    visibility: Global___ModerationVisibility.ValueType
    """Required for APPROVE / HIDE"""
    reason: builtins.str
    priority: builtins.int
    """New priority for SET_PRIORITY; initial priority for FLAG"""
    queue_item_id: builtins.int
    """Target flag for SET_PRIORITY / UNFLAG"""
    trigger: Global___ModerationTrigger.ValueType
    """Provenance for FLAG"""
    supersede_queue_item_id: builtins.int
    """For FLAG: resolve this flag as the new one opens"""
    clear_flags: builtins.bool
    """For APPROVE / HIDE: also resolve all open flags on the state"""
    def __init__(
        self,
        *,
        moderation_state_id: builtins.int | None = ...,
        action: Global___ModerationAction.ValueType | None = ...,
        visibility: Global___ModerationVisibility.ValueType | None = ...,
        reason: builtins.str | None = ...,
        priority: builtins.int | None = ...,
        queue_item_id: builtins.int | None = ...,
        trigger: Global___ModerationTrigger.ValueType | None = ...,
        supersede_queue_item_id: builtins.int | None = ...,
        clear_flags: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["action", b"action", "clear_flags", b"clear_flags", "moderation_state_id", b"moderation_state_id", "priority", b"priority", "queue_item_id", b"queue_item_id", "reason", b"reason", "supersede_queue_item_id", b"supersede_queue_item_id", "trigger", b"trigger", "visibility", b"visibility"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ModerateContentReq: typing_extensions.TypeAlias = ModerateContentReq

@typing.final
class ModerateContentRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATE_FIELD_NUMBER: builtins.int
    @property
    def moderation_state(self) -> Global___ModerationStateInfo: ...
    def __init__(
        self,
        *,
        moderation_state: Global___ModerationStateInfo | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_state", b"moderation_state"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ModerateContentRes: typing_extensions.TypeAlias = ModerateContentRes

@typing.final
class SetUserContentVisibilityReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    VISIBILITY_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    FROM_VISIBILITY_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    visibility: Global___ModerationVisibility.ValueType
    """must be set"""
    reason: builtins.str
    """optional; free-form admin note recorded in ModerationLog"""
    @property
    def from_visibility(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[Global___ModerationVisibility.ValueType]:
        """If non-empty, only sweep states currently at one of these visibilities. Empty = any visibility (default)."""

    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
        visibility: Global___ModerationVisibility.ValueType | None = ...,
        reason: builtins.str | None = ...,
        from_visibility: collections.abc.Iterable[Global___ModerationVisibility.ValueType] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["from_visibility", b"from_visibility", "reason", b"reason", "user_id", b"user_id", "visibility", b"visibility"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetUserContentVisibilityReq: typing_extensions.TypeAlias = SetUserContentVisibilityReq

@typing.final
class SetUserContentVisibilityRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATED_COUNT_FIELD_NUMBER: builtins.int
    updated_count: builtins.int
    """number of ModerationState rows whose visibility changed"""
    def __init__(
        self,
        *,
        updated_count: builtins.int | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["updated_count", b"updated_count"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___SetUserContentVisibilityRes: typing_extensions.TypeAlias = SetUserContentVisibilityRes

@typing.final
class ListModerationStatesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTHOR_USER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    NEWEST_FIRST_FIELD_NUMBER: builtins.int
    author_user_id: builtins.int
    """Filter to states authored by this user (optional)"""
    page_size: builtins.int
    page_token: builtins.str
    newest_first: builtins.bool
    """Order by newest first (default: false = oldest first)"""
    def __init__(
        self,
        *,
        author_user_id: builtins.int | None = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        newest_first: builtins.bool | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["author_user_id", b"author_user_id", "newest_first", b"newest_first", "page_size", b"page_size", "page_token", b"page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListModerationStatesReq: typing_extensions.TypeAlias = ListModerationStatesReq

@typing.final
class ListModerationStatesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODERATION_STATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def moderation_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___ModerationStateInfo]: ...
    def __init__(
        self,
        *,
        moderation_states: collections.abc.Iterable[Global___ModerationStateInfo] | None = ...,
        next_page_token: builtins.str | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["moderation_states", b"moderation_states", "next_page_token", b"next_page_token"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___ListModerationStatesRes: typing_extensions.TypeAlias = ListModerationStatesRes



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import account_pb2
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class AccountStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetAccountInfo: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.GetAccountInfoRes]
    """account management APIs
    Get information about the user's account
    """
    ChangePasswordV2: grpc.UnaryUnaryMultiCallable[account_pb2.ChangePasswordV2Req, google.protobuf.empty_pb2.Empty]
    """Change the user's password
    we will send and an email to the user saying their password was changed
    """
    ChangeEmailV2: grpc.UnaryUnaryMultiCallable[account_pb2.ChangeEmailV2Req, google.protobuf.empty_pb2.Empty]
    """Change the user's email address
    We will send a notification email to the old email, and confirmation email to the new email
    Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
    """
    GetContributorFormInfo: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.GetContributorFormInfoRes]
    """Returns info related to filling out the contributor form"""
    FillContributorForm: grpc.UnaryUnaryMultiCallable[account_pb2.FillContributorFormReq, google.protobuf.empty_pb2.Empty]
    """Fill the contributor form; this can be done multiple times"""
    ChangeLanguagePreference: grpc.UnaryUnaryMultiCallable[account_pb2.ChangeLanguagePreferenceReq, google.protobuf.empty_pb2.Empty]
    """Changes the user's interface language"""
    ChangePhone: grpc.UnaryUnaryMultiCallable[account_pb2.ChangePhoneReq, google.protobuf.empty_pb2.Empty]
    """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
    And returned in a call to in VerifyPhone() to complete the phone number change.
    An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
    A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
    An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
    """
    VerifyPhone: grpc.UnaryUnaryMultiCallable[account_pb2.VerifyPhoneReq, google.protobuf.empty_pb2.Empty]
    """Enter the code you got in the sms. Other accounts using the same phone number will
    lose their verification status.
    """
    InitiateStrongVerification: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.InitiateStrongVerificationRes]
    """Initiates a strong verification (passport read)"""
    GetStrongVerificationAttemptStatus: grpc.UnaryUnaryMultiCallable[account_pb2.GetStrongVerificationAttemptStatusReq, account_pb2.GetStrongVerificationAttemptStatusRes]
    """Gets the status of a strong verification attempt"""
    DeleteStrongVerificationData: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.protobuf.empty_pb2.Empty]
    """Deletes full SV data (but not minimal data), see the ToS"""
    DeleteAccount: grpc.UnaryUnaryMultiCallable[account_pb2.DeleteAccountReq, google.protobuf.empty_pb2.Empty]
    """Sends email with confirmation link containing token to delete account"""
    ListModNotes: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.ListModNotesRes]
    """Lists all the user's mod notes: only ack'd ones because otherwise the user is jailed"""
    ListActiveSessions: grpc.UnaryUnaryMultiCallable[account_pb2.ListActiveSessionsReq, account_pb2.ListActiveSessionsRes]
    """Lists all the user's current sessions"""
    LogOutSession: grpc.UnaryUnaryMultiCallable[account_pb2.LogOutSessionReq, google.protobuf.empty_pb2.Empty]
    """Logs the user out of the given session, cannot be current one"""
    LogOutOtherSessions: grpc.UnaryUnaryMultiCallable[account_pb2.LogOutOtherSessionsReq, google.protobuf.empty_pb2.Empty]
    """Logs the user out of all other sessions except this one"""
    SetProfilePublicVisibility: grpc.UnaryUnaryMultiCallable[account_pb2.SetProfilePublicVisibilityReq, google.protobuf.empty_pb2.Empty]
    """Set what info is shown to logged-out users"""
    CreateInviteCode: grpc.UnaryUnaryMultiCallable[account_pb2.CreateInviteCodeReq, account_pb2.CreateInviteCodeRes]
    """Creates a new unique invite code for the current user"""
    DisableInviteCode: grpc.UnaryUnaryMultiCallable[account_pb2.DisableInviteCodeReq, google.protobuf.empty_pb2.Empty]
    """Disables the given invite code created by the user"""
    ListInviteCodes: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.ListInviteCodesRes]
    """Lists all invite codes created by the user, with usage count"""
    GetReminders: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.GetRemindersRes]
    """Reminders to be shown on dashboard for things the user should do"""
    GetMyVolunteerInfo: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, account_pb2.GetMyVolunteerInfoRes]
    """Returns info about the current user's volunteer status if they are volunteer"""
    UpdateMyVolunteerInfo: grpc.UnaryUnaryMultiCallable[account_pb2.UpdateMyVolunteerInfoReq, account_pb2.GetMyVolunteerInfoRes]
    """Updates the current user's volunteer status if they are volunteer"""

class AccountServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetAccountInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetAccountInfoRes:
        """account management APIs
        Get information about the user's account
        """

    @abc.abstractmethod
    def ChangePasswordV2(
        self,
        request: account_pb2.ChangePasswordV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Change the user's password
        we will send and an email to the user saying their password was changed
        """

    @abc.abstractmethod
    def ChangeEmailV2(
        self,
        request: account_pb2.ChangeEmailV2Req,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Change the user's email address
        We will send a notification email to the old email, and confirmation email to the new email
        Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
        """

    @abc.abstractmethod
    def GetContributorFormInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetContributorFormInfoRes:
        """Returns info related to filling out the contributor form"""

    @abc.abstractmethod
    def FillContributorForm(
        self,
        request: account_pb2.FillContributorFormReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Fill the contributor form; this can be done multiple times"""

    @abc.abstractmethod
    def ChangeLanguagePreference(
        self,
        request: account_pb2.ChangeLanguagePreferenceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Changes the user's interface language"""

    @abc.abstractmethod
    def ChangePhone(
        self,
        request: account_pb2.ChangePhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
        And returned in a call to in VerifyPhone() to complete the phone number change.
        An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
        A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
        An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
        """

    @abc.abstractmethod
    def VerifyPhone(
        self,
        request: account_pb2.VerifyPhoneReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Enter the code you got in the sms. Other accounts using the same phone number will
        lose their verification status.
        """

    @abc.abstractmethod
    def InitiateStrongVerification(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.InitiateStrongVerificationRes:
        """Initiates a strong verification (passport read)"""

    @abc.abstractmethod
    def GetStrongVerificationAttemptStatus(
        self,
        request: account_pb2.GetStrongVerificationAttemptStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetStrongVerificationAttemptStatusRes:
        """Gets the status of a strong verification attempt"""

    @abc.abstractmethod
    def DeleteStrongVerificationData(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Deletes full SV data (but not minimal data), see the ToS"""

    @abc.abstractmethod
    def DeleteAccount(
        self,
        request: account_pb2.DeleteAccountReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Sends email with confirmation link containing token to delete account"""

    @abc.abstractmethod
    def ListModNotes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.ListModNotesRes:
        """Lists all the user's mod notes: only ack'd ones because otherwise the user is jailed"""

    @abc.abstractmethod
    def ListActiveSessions(
        self,
        request: account_pb2.ListActiveSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.ListActiveSessionsRes:
        """Lists all the user's current sessions"""

    @abc.abstractmethod
    def LogOutSession(
        self,
        request: account_pb2.LogOutSessionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Logs the user out of the given session, cannot be current one"""

    @abc.abstractmethod
    def LogOutOtherSessions(
        self,
        request: account_pb2.LogOutOtherSessionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Logs the user out of all other sessions except this one"""

    @abc.abstractmethod
    def SetProfilePublicVisibility(
        self,
        request: account_pb2.SetProfilePublicVisibilityReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Set what info is shown to logged-out users"""

    @abc.abstractmethod
    def CreateInviteCode(
        self,
        request: account_pb2.CreateInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.CreateInviteCodeRes:
        """Creates a new unique invite code for the current user"""

    @abc.abstractmethod
    def DisableInviteCode(
        self,
        request: account_pb2.DisableInviteCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Disables the given invite code created by the user"""

    @abc.abstractmethod
    def ListInviteCodes(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.ListInviteCodesRes:
        """Lists all invite codes created by the user, with usage count"""

    @abc.abstractmethod
    def GetReminders(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetRemindersRes:
        """Reminders to be shown on dashboard for things the user should do"""

    @abc.abstractmethod
    def GetMyVolunteerInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetMyVolunteerInfoRes:
        """Returns info about the current user's volunteer status if they are volunteer"""

    @abc.abstractmethod
    def UpdateMyVolunteerInfo(
        self,
        request: account_pb2.UpdateMyVolunteerInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> account_pb2.GetMyVolunteerInfoRes:
        """Updates the current user's volunteer status if they are volunteer"""

def add_AccountServicer_to_server(servicer: AccountServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import public_trips_pb2 as public__trips__pb2


class PublicTripsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreatePublicTrip = channel.unary_unary(
                '/org.couchers.api.public_trips.PublicTrips/CreatePublicTrip',
                request_serializer=public__trips__pb2.CreatePublicTripReq.SerializeToString,
                response_deserializer=public__trips__pb2.PublicTrip.FromString,
                )
        self.GetPublicTrip = channel.unary_unary(
                '/org.couchers.api.public_trips.PublicTrips/GetPublicTrip',
                request_serializer=public__trips__pb2.GetPublicTripReq.SerializeToString,
                response_deserializer=public__trips__pb2.PublicTrip.FromString,
                )
        self.ListPublicTrips = channel.unary_unary(
                '/org.couchers.api.public_trips.PublicTrips/ListPublicTrips',
                request_serializer=public__trips__pb2.ListPublicTripsReq.SerializeToString,
                response_deserializer=public__trips__pb2.ListPublicTripsRes.FromString,
                )
        self.ListPublicTripsByUser = channel.unary_unary(
                '/org.couchers.api.public_trips.PublicTrips/ListPublicTripsByUser',
                request_serializer=public__trips__pb2.ListPublicTripsByUserReq.SerializeToString,
                response_deserializer=public__trips__pb2.ListPublicTripsByUserRes.FromString,
                )
        self.UpdatePublicTrip = channel.unary_unary(
                '/org.couchers.api.public_trips.PublicTrips/UpdatePublicTrip',
                request_serializer=public__trips__pb2.UpdatePublicTripReq.SerializeToString,
                response_deserializer=public__trips__pb2.PublicTrip.FromString,
                )


class PublicTripsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreatePublicTrip(self, request, context):
        """Create a new public trip in a community
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPublicTrip(self, request, context):
        """Get details of a public trip
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPublicTrips(self, request, context):
        """List public trips in a community (for hosts browsing)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPublicTripsByUser(self, request, context):
        """List a user's public trips. Used for both the user's own dashboard and
        for showing upcoming trips on another user's profile.
        - If user_id matches the caller, all trips (including closed/past) are returned.
        - Otherwise only active, upcoming trips are returned.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePublicTrip(self, request, context):
        """Edit a public trip. Owner-only. Content edits (dates, description)
        require the trip's end date to be today or later. Status can be set to
        CLOSED at any time, or back to SEARCHING_FOR_HOST as long as the trip is
        not in the past.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PublicTripsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreatePublicTrip': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePublicTrip,
                    request_deserializer=public__trips__pb2.CreatePublicTripReq.FromString,
                    response_serializer=public__trips__pb2.PublicTrip.SerializeToString,
            ),
            'GetPublicTrip': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPublicTrip,
                    request_deserializer=public__trips__pb2.GetPublicTripReq.FromString,
                    response_serializer=public__trips__pb2.PublicTrip.SerializeToString,
            ),
            'ListPublicTrips': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPublicTrips,
                    request_deserializer=public__trips__pb2.ListPublicTripsReq.FromString,
                    response_serializer=public__trips__pb2.ListPublicTripsRes.SerializeToString,
            ),
            'ListPublicTripsByUser': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPublicTripsByUser,
                    request_deserializer=public__trips__pb2.ListPublicTripsByUserReq.FromString,
                    response_serializer=public__trips__pb2.ListPublicTripsByUserRes.SerializeToString,
            ),
            'UpdatePublicTrip': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePublicTrip,
                    request_deserializer=public__trips__pb2.UpdatePublicTripReq.FromString,
                    response_serializer=public__trips__pb2.PublicTrip.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.public_trips.PublicTrips', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PublicTrips(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreatePublicTrip(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.public_trips.PublicTrips/CreatePublicTrip',
            public__trips__pb2.CreatePublicTripReq.SerializeToString,
            public__trips__pb2.PublicTrip.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPublicTrip(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.public_trips.PublicTrips/GetPublicTrip',
            public__trips__pb2.GetPublicTripReq.SerializeToString,
            public__trips__pb2.PublicTrip.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPublicTrips(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.public_trips.PublicTrips/ListPublicTrips',
            public__trips__pb2.ListPublicTripsReq.SerializeToString,
            public__trips__pb2.ListPublicTripsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPublicTripsByUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.public_trips.PublicTrips/ListPublicTripsByUser',
            public__trips__pb2.ListPublicTripsByUserReq.SerializeToString,
            public__trips__pb2.ListPublicTripsByUserRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePublicTrip(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.public_trips.PublicTrips/UpdatePublicTrip',
            public__trips__pb2.UpdatePublicTripReq.SerializeToString,
            public__trips__pb2.PublicTrip.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import postal_verification_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PostalVerificationStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    InitiatePostalVerification: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.InitiatePostalVerificationReq, postal_verification_pb2.InitiatePostalVerificationRes]
    """Step 1: Submit address for validation
    Validates and normalizes the address. Returns a corrected address for user confirmation.
    Returns FAILED_PRECONDITION if there's already an active attempt.
    Returns RESOURCE_EXHAUSTED if rate limited (one attempt per 30 days).
    """
    ConfirmPostalAddress: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.ConfirmPostalAddressReq, postal_verification_pb2.ConfirmPostalAddressRes]
    """Step 2: Confirm the (possibly corrected) address and send postcard
    Confirms the address and queues postcard for sending.
    Returns NOT_FOUND if attempt doesn't exist.
    Returns FAILED_PRECONDITION if attempt is not in pending_address_confirmation state.
    """
    GetPostalVerificationStatus: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.GetPostalVerificationStatusReq, postal_verification_pb2.GetPostalVerificationStatusRes]
    """Get current postal verification status
    Returns the user's postal verification status and current/latest attempt details.
    """
    VerifyPostalCode: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.VerifyPostalCodeReq, postal_verification_pb2.VerifyPostalCodeRes]
    """Submit verification code (from postcard or QR code)
    Verifies the code from the postcard.
    Returns NOT_FOUND if attempt doesn't exist.
    Returns FAILED_PRECONDITION if attempt is not in awaiting_verification state.
    """
    CancelPostalVerification: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.CancelPostalVerificationReq, google.protobuf.empty_pb2.Empty]
    """Cancel an in-progress attempt
    Cancels an active postal verification attempt.
    Returns NOT_FOUND if attempt doesn't exist.
    Returns FAILED_PRECONDITION if attempt is not cancellable.
    """
    ListPostalVerificationAttempts: grpc.UnaryUnaryMultiCallable[postal_verification_pb2.ListPostalVerificationAttemptsReq, postal_verification_pb2.ListPostalVerificationAttemptsRes]
    """List all postal verification attempts (history)
    Returns all postal verification attempts for the user.
    """

class PostalVerificationServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def InitiatePostalVerification(
        self,
        request: postal_verification_pb2.InitiatePostalVerificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> postal_verification_pb2.InitiatePostalVerificationRes:
        """Step 1: Submit address for validation
        Validates and normalizes the address. Returns a corrected address for user confirmation.
        Returns FAILED_PRECONDITION if there's already an active attempt.
        Returns RESOURCE_EXHAUSTED if rate limited (one attempt per 30 days).
        """

    @abc.abstractmethod
    def ConfirmPostalAddress(
        self,
        request: postal_verification_pb2.ConfirmPostalAddressReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> postal_verification_pb2.ConfirmPostalAddressRes:
        """Step 2: Confirm the (possibly corrected) address and send postcard
        Confirms the address and queues postcard for sending.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not in pending_address_confirmation state.
        """

    @abc.abstractmethod
    def GetPostalVerificationStatus(
        self,
        request: postal_verification_pb2.GetPostalVerificationStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> postal_verification_pb2.GetPostalVerificationStatusRes:
        """Get current postal verification status
        Returns the user's postal verification status and current/latest attempt details.
        """

    @abc.abstractmethod
    def VerifyPostalCode(
        self,
        request: postal_verification_pb2.VerifyPostalCodeReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> postal_verification_pb2.VerifyPostalCodeRes:
        """Submit verification code (from postcard or QR code)
        Verifies the code from the postcard.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not in awaiting_verification state.
        """

    @abc.abstractmethod
    def CancelPostalVerification(
        self,
        request: postal_verification_pb2.CancelPostalVerificationReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Cancel an in-progress attempt
        Cancels an active postal verification attempt.
        Returns NOT_FOUND if attempt doesn't exist.
        Returns FAILED_PRECONDITION if attempt is not cancellable.
        """

    @abc.abstractmethod
    def ListPostalVerificationAttempts(
        self,
        request: postal_verification_pb2.ListPostalVerificationAttemptsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> postal_verification_pb2.ListPostalVerificationAttemptsRes:
        """List all postal verification attempts (history)
        Returns all postal verification attempts for the user.
        """

def add_PostalVerificationServicer_to_server(servicer: PostalVerificationServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: annotations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61nnotations.proto\x1a google/protobuf/descriptor.proto*\x93\x01\n\tAuthLevel\x12\x16\n\x12\x41UTH_LEVEL_UNKNOWN\x10\x00\x12\x13\n\x0f\x41UTH_LEVEL_OPEN\x10\x01\x12\x15\n\x11\x41UTH_LEVEL_JAILED\x10\x02\x12\x15\n\x11\x41UTH_LEVEL_SECURE\x10\x03\x12\x15\n\x11\x41UTH_LEVEL_EDITOR\x10\x05\x12\x14\n\x10\x41UTH_LEVEL_ADMIN\x10\x04:2\n\tsensitive\x12\x1d.google.protobuf.FieldOptions\x18\xd0\x86\x03 \x01(\x08:1\n\x08is_token\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x08:A\n\nauth_level\x12\x1f.google.protobuf.ServiceOptions\x18\xd1\x86\x03 \x01(\x0e\x32\n.AuthLevelb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'annotations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AUTHLEVEL']._serialized_start=56
  _globals['_AUTHLEVEL']._serialized_end=203
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import resources_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ResourcesStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetTermsOfService: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, resources_pb2.GetTermsOfServiceRes]
    """This API contains general resources needed by frontends and managed by the backend team

    Returns the latest Terms of Service markdown, to be shown on signup or if jailed due to this
    """
    GetCommunityGuidelines: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, resources_pb2.GetCommunityGuidelinesRes]
    """Returns the latest Community Guidelines, see GetCommunityGuidelinesRes
    Each of the Community Guidelines should be shown under the text "Please agree to our Community Guidelines", and
    each Community Guideline should be shown with its title, the logo, and the guideline content. The user needs to
    tick a checkbox to agree each of the individual Guidelines and the frontend should only say a user agreed to them
    if they agreed to each one individually.
    """
    GetRegions: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, resources_pb2.GetRegionsRes]
    """Returns a list of allowed regions"""
    GetLanguages: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, resources_pb2.GetLanguagesRes]
    """Returns a list of allowed languages. This is a subset of the full ISO639-3 table."""
    GetBadges: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, resources_pb2.GetBadgesRes]
    """Returns a list of possible profile badges"""

class ResourcesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetTermsOfService(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> resources_pb2.GetTermsOfServiceRes:
        """This API contains general resources needed by frontends and managed by the backend team

        Returns the latest Terms of Service markdown, to be shown on signup or if jailed due to this
        """

    @abc.abstractmethod
    def GetCommunityGuidelines(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> resources_pb2.GetCommunityGuidelinesRes:
        """Returns the latest Community Guidelines, see GetCommunityGuidelinesRes
        Each of the Community Guidelines should be shown under the text "Please agree to our Community Guidelines", and
        each Community Guideline should be shown with its title, the logo, and the guideline content. The user needs to
        tick a checkbox to agree each of the individual Guidelines and the frontend should only say a user agreed to them
        if they agreed to each one individually.
        """

    @abc.abstractmethod
    def GetRegions(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> resources_pb2.GetRegionsRes:
        """Returns a list of allowed regions"""

    @abc.abstractmethod
    def GetLanguages(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> resources_pb2.GetLanguagesRes:
        """Returns a list of allowed languages. This is a subset of the full ISO639-3 table."""

    @abc.abstractmethod
    def GetBadges(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> resources_pb2.GetBadgesRes:
        """Returns a list of possible profile badges"""

def add_ResourcesServicer_to_server(servicer: ResourcesServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: donations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x64onations.proto\x12\x1aorg.couchers.api.donations\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"H\n\x13InitiateDonationReq\x12\x0e\n\x06\x61mount\x18\x01 \x01(\r\x12\x11\n\trecurring\x18\x02 \x01(\x08\x12\x0e\n\x06source\x18\x03 \x01(\t\"V\n\x13InitiateDonationRes\x12\"\n\x1astripe_checkout_session_id\x18\x01 \x01(\t\x12\x1b\n\x13stripe_checkout_url\x18\x02 \x01(\t\"5\n\x18GetDonationPortalLinkRes\x12\x19\n\x11stripe_portal_url\x18\x01 \x01(\t2\xf2\x01\n\tDonations\x12v\n\x10InitiateDonation\x12/.org.couchers.api.donations.InitiateDonationReq\x1a/.org.couchers.api.donations.InitiateDonationRes\"\x00\x12g\n\x15GetDonationPortalLink\x12\x16.google.protobuf.Empty\x1a\x34.org.couchers.api.donations.GetDonationPortalLinkRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'donations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DONATIONS']._loaded_options = None
  _globals['_DONATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_INITIATEDONATIONREQ']._serialized_start=95
  _globals['_INITIATEDONATIONREQ']._serialized_end=167
  _globals['_INITIATEDONATIONRES']._serialized_start=169
  _globals['_INITIATEDONATIONRES']._serialized_end=255
  _globals['_GETDONATIONPORTALLINKRES']._serialized_start=257
  _globals['_GETDONATIONPORTALLINKRES']._serialized_end=310
  _globals['_DONATIONS']._serialized_start=313
  _globals['_DONATIONS']._serialized_end=555
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.api.httpbody_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import public_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class PublicStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetPublicUsers: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, google.api.httpbody_pb2.HttpBody]
    GetPublicUser: grpc.UnaryUnaryMultiCallable[public_pb2.GetPublicUserReq, public_pb2.GetPublicUserRes]
    GetSignupPageInfo: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, public_pb2.GetSignupPageInfoRes]
    GetVolunteers: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, public_pb2.GetVolunteersRes]
    GetDonationStats: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, public_pb2.GetDonationStatsRes]

class PublicServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetPublicUsers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.api.httpbody_pb2.HttpBody: ...

    @abc.abstractmethod
    def GetPublicUser(
        self,
        request: public_pb2.GetPublicUserReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_pb2.GetPublicUserRes: ...

    @abc.abstractmethod
    def GetSignupPageInfo(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_pb2.GetSignupPageInfoRes: ...

    @abc.abstractmethod
    def GetVolunteers(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_pb2.GetVolunteersRes: ...

    @abc.abstractmethod
    def GetDonationStats(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> public_pb2.GetDonationStatsRes: ...

def add_PublicServicer_to_server(servicer: PublicServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import account_pb2
import builtins
import discussions_pb2
import events_pb2
import google.protobuf.descriptor
import google.protobuf.message
import requests_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDashboardV2Req(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___GetDashboardV2Req: typing_extensions.TypeAlias = GetDashboardV2Req

@typing.final
class GetDashboardV2Res(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REMINDERS_FIELD_NUMBER: builtins.int
    SURFING_FIELD_NUMBER: builtins.int
    HOSTING_FIELD_NUMBER: builtins.int
    MY_EVENTS_FIELD_NUMBER: builtins.int
    COMMUNITY_EVENTS_FIELD_NUMBER: builtins.int
    DISCUSSIONS_FIELD_NUMBER: builtins.int
    @property
    def reminders(self) -> account_pb2.GetRemindersRes: ...
    @property
    def surfing(self) -> requests_pb2.ListHostRequestsRes: ...
    @property
    def hosting(self) -> requests_pb2.ListHostRequestsRes: ...
    @property
    def my_events(self) -> events_pb2.ListMyEventsRes: ...
    @property
    def community_events(self) -> events_pb2.ListMyEventsRes: ...
    @property
    def discussions(self) -> discussions_pb2.ListMyCommunitiesDiscussionsRes: ...
    def __init__(
        self,
        *,
        reminders: account_pb2.GetRemindersRes | None = ...,
        surfing: requests_pb2.ListHostRequestsRes | None = ...,
        hosting: requests_pb2.ListHostRequestsRes | None = ...,
        my_events: events_pb2.ListMyEventsRes | None = ...,
        community_events: events_pb2.ListMyEventsRes | None = ...,
        discussions: discussions_pb2.ListMyCommunitiesDiscussionsRes | None = ...,
    ) -> None: ...
    _HasFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_events", b"community_events", "discussions", b"discussions", "hosting", b"hosting", "my_events", b"my_events", "reminders", b"reminders", "surfing", b"surfing"]
    def HasField(self, field_name: _HasFieldArgType) -> builtins.bool: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["community_events", b"community_events", "discussions", b"discussions", "hosting", b"hosting", "my_events", b"my_events", "reminders", b"reminders", "surfing", b"surfing"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___GetDashboardV2Res: typing_extensions.TypeAlias = GetDashboardV2Res



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import notifications_pb2 as notifications__pb2


class NotificationsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetNotificationSettings = channel.unary_unary(
                '/org.couchers.notifications.Notifications/GetNotificationSettings',
                request_serializer=notifications__pb2.GetNotificationSettingsReq.SerializeToString,
                response_deserializer=notifications__pb2.GetNotificationSettingsRes.FromString,
                )
        self.SetNotificationSettings = channel.unary_unary(
                '/org.couchers.notifications.Notifications/SetNotificationSettings',
                request_serializer=notifications__pb2.SetNotificationSettingsReq.SerializeToString,
                response_deserializer=notifications__pb2.GetNotificationSettingsRes.FromString,
                )
        self.ListNotifications = channel.unary_unary(
                '/org.couchers.notifications.Notifications/ListNotifications',
                request_serializer=notifications__pb2.ListNotificationsReq.SerializeToString,
                response_deserializer=notifications__pb2.ListNotificationsRes.FromString,
                )
        self.MarkNotificationSeen = channel.unary_unary(
                '/org.couchers.notifications.Notifications/MarkNotificationSeen',
                request_serializer=notifications__pb2.MarkNotificationSeenReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.MarkAllNotificationsSeen = channel.unary_unary(
                '/org.couchers.notifications.Notifications/MarkAllNotificationsSeen',
                request_serializer=notifications__pb2.MarkAllNotificationsSeenReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetVapidPublicKey = channel.unary_unary(
                '/org.couchers.notifications.Notifications/GetVapidPublicKey',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=notifications__pb2.GetVapidPublicKeyRes.FromString,
                )
        self.RegisterPushNotificationSubscription = channel.unary_unary(
                '/org.couchers.notifications.Notifications/RegisterPushNotificationSubscription',
                request_serializer=notifications__pb2.RegisterPushNotificationSubscriptionReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendTestPushNotification = channel.unary_unary(
                '/org.couchers.notifications.Notifications/SendTestPushNotification',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RegisterMobilePushNotificationSubscription = channel.unary_unary(
                '/org.couchers.notifications.Notifications/RegisterMobilePushNotificationSubscription',
                request_serializer=notifications__pb2.RegisterMobilePushNotificationSubscriptionReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendTestMobilePushNotification = channel.unary_unary(
                '/org.couchers.notifications.Notifications/SendTestMobilePushNotification',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SendDevPushNotification = channel.unary_unary(
                '/org.couchers.notifications.Notifications/SendDevPushNotification',
                request_serializer=notifications__pb2.SendDevPushNotificationReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DebugRedeliverPushNotification = channel.unary_unary(
                '/org.couchers.notifications.Notifications/DebugRedeliverPushNotification',
                request_serializer=notifications__pb2.DebugRedeliverPushNotificationReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class NotificationsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetNotificationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetNotificationSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNotifications(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkNotificationSeen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MarkAllNotificationsSeen(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVapidPublicKey(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterPushNotificationSubscription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendTestPushNotification(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterMobilePushNotificationSubscription(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendTestMobilePushNotification(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendDevPushNotification(self, request, context):
        """Development API: Send an arbitrary push notification to the current user.
        Gated behind ENABLE_DEV_APIS config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DebugRedeliverPushNotification(self, request, context):
        """Debug API: Redeliver a push notification by notification_id.
        Gated behind ENABLE_DEV_APIS config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetNotificationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotificationSettings,
                    request_deserializer=notifications__pb2.GetNotificationSettingsReq.FromString,
                    response_serializer=notifications__pb2.GetNotificationSettingsRes.SerializeToString,
            ),
            'SetNotificationSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetNotificationSettings,
                    request_deserializer=notifications__pb2.SetNotificationSettingsReq.FromString,
                    response_serializer=notifications__pb2.GetNotificationSettingsRes.SerializeToString,
            ),
            'ListNotifications': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotifications,
                    request_deserializer=notifications__pb2.ListNotificationsReq.FromString,
                    response_serializer=notifications__pb2.ListNotificationsRes.SerializeToString,
            ),
            'MarkNotificationSeen': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkNotificationSeen,
                    request_deserializer=notifications__pb2.MarkNotificationSeenReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'MarkAllNotificationsSeen': grpc.unary_unary_rpc_method_handler(
                    servicer.MarkAllNotificationsSeen,
                    request_deserializer=notifications__pb2.MarkAllNotificationsSeenReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetVapidPublicKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVapidPublicKey,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=notifications__pb2.GetVapidPublicKeyRes.SerializeToString,
            ),
            'RegisterPushNotificationSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterPushNotificationSubscription,
                    request_deserializer=notifications__pb2.RegisterPushNotificationSubscriptionReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendTestPushNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendTestPushNotification,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RegisterMobilePushNotificationSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterMobilePushNotificationSubscription,
                    request_deserializer=notifications__pb2.RegisterMobilePushNotificationSubscriptionReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendTestMobilePushNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendTestMobilePushNotification,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SendDevPushNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.SendDevPushNotification,
                    request_deserializer=notifications__pb2.SendDevPushNotificationReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DebugRedeliverPushNotification': grpc.unary_unary_rpc_method_handler(
                    servicer.DebugRedeliverPushNotification,
                    request_deserializer=notifications__pb2.DebugRedeliverPushNotificationReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.notifications.Notifications', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Notifications(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetNotificationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/GetNotificationSettings',
            notifications__pb2.GetNotificationSettingsReq.SerializeToString,
            notifications__pb2.GetNotificationSettingsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetNotificationSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/SetNotificationSettings',
            notifications__pb2.SetNotificationSettingsReq.SerializeToString,
            notifications__pb2.GetNotificationSettingsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNotifications(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/ListNotifications',
            notifications__pb2.ListNotificationsReq.SerializeToString,
            notifications__pb2.ListNotificationsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkNotificationSeen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/MarkNotificationSeen',
            notifications__pb2.MarkNotificationSeenReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MarkAllNotificationsSeen(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/MarkAllNotificationsSeen',
            notifications__pb2.MarkAllNotificationsSeenReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVapidPublicKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/GetVapidPublicKey',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            notifications__pb2.GetVapidPublicKeyRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterPushNotificationSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/RegisterPushNotificationSubscription',
            notifications__pb2.RegisterPushNotificationSubscriptionReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendTestPushNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/SendTestPushNotification',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterMobilePushNotificationSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/RegisterMobilePushNotificationSubscription',
            notifications__pb2.RegisterMobilePushNotificationSubscriptionReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendTestMobilePushNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/SendTestMobilePushNotification',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendDevPushNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/SendDevPushNotification',
            notifications__pb2.SendDevPushNotificationReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DebugRedeliverPushNotification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.notifications.Notifications/DebugRedeliverPushNotification',
            notifications__pb2.DebugRedeliverPushNotificationReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import discussions_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class DiscussionsStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    CreateDiscussion: grpc.UnaryUnaryMultiCallable[discussions_pb2.CreateDiscussionReq, discussions_pb2.Discussion]
    """Create a new discussion"""
    GetDiscussion: grpc.UnaryUnaryMultiCallable[discussions_pb2.GetDiscussionReq, discussions_pb2.Discussion]
    """Retrieve a discussion"""
    ListMyCommunitiesDiscussions: grpc.UnaryUnaryMultiCallable[discussions_pb2.ListMyCommunitiesDiscussionsReq, discussions_pb2.ListMyCommunitiesDiscussionsRes]
    """List recent discussions from all communities the user belongs to, newest first"""
    UpdateDiscussion: grpc.UnaryUnaryMultiCallable[discussions_pb2.UpdateDiscussionReq, discussions_pb2.Discussion]
    """Update a discussion; only the creator can edit"""
    DeleteDiscussion: grpc.UnaryUnaryMultiCallable[discussions_pb2.DeleteDiscussionReq, google.protobuf.empty_pb2.Empty]
    """Delete a discussion; creator or community moderator can delete"""

class DiscussionsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateDiscussion(
        self,
        request: discussions_pb2.CreateDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> discussions_pb2.Discussion:
        """Create a new discussion"""

    @abc.abstractmethod
    def GetDiscussion(
        self,
        request: discussions_pb2.GetDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> discussions_pb2.Discussion:
        """Retrieve a discussion"""

    @abc.abstractmethod
    def ListMyCommunitiesDiscussions(
        self,
        request: discussions_pb2.ListMyCommunitiesDiscussionsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> discussions_pb2.ListMyCommunitiesDiscussionsRes:
        """List recent discussions from all communities the user belongs to, newest first"""

    @abc.abstractmethod
    def UpdateDiscussion(
        self,
        request: discussions_pb2.UpdateDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> discussions_pb2.Discussion:
        """Update a discussion; only the creator can edit"""

    @abc.abstractmethod
    def DeleteDiscussion(
        self,
        request: discussions_pb2.DeleteDiscussionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Delete a discussion; creator or community moderator can delete"""

def add_DiscussionsServicer_to_server(servicer: DiscussionsServicer, server: grpc.Server) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: conversations.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63onversations.proto\x12\x1eorg.couchers.api.conversations\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\"\"\n\x12MessageContentText\x12\x0c\n\x04text\x18\x01 \x01(\t\"\x1b\n\x19MessageContentChatCreated\"\x1a\n\x18MessageContentChatEdited\"3\n\x19MessageContentUserInvited\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"\x18\n\x16MessageContentUserLeft\"5\n\x1bMessageContentUserMadeAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"8\n\x1eMessageContentUserRemovedAdmin\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"3\n\x19MessageContentUserRemoved\x12\x16\n\x0etarget_user_id\x18\x01 \x01(\x04\"k\n&MessageContentHostRequestStatusChanged\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.org.couchers.api.conversations.HostRequestStatus\"\xf5\x06\n\x07Message\x12\x12\n\nmessage_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x61uthor_user_id\x18\x02 \x01(\x04\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x04text\x18\x04 \x01(\x0b\x32\x32.org.couchers.api.conversations.MessageContentTextH\x00\x12Q\n\x0c\x63hat_created\x18\x05 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentChatCreatedH\x00\x12O\n\x0b\x63hat_edited\x18\x06 \x01(\x0b\x32\x38.org.couchers.api.conversations.MessageContentChatEditedH\x00\x12Q\n\x0cuser_invited\x18\x07 \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserInvitedH\x00\x12K\n\tuser_left\x18\x08 \x01(\x0b\x32\x36.org.couchers.api.conversations.MessageContentUserLeftH\x00\x12V\n\x0fuser_made_admin\x18\t \x01(\x0b\x32;.org.couchers.api.conversations.MessageContentUserMadeAdminH\x00\x12\\\n\x12user_removed_admin\x18\n \x01(\x0b\x32>.org.couchers.api.conversations.MessageContentUserRemovedAdminH\x00\x12m\n\x1bhost_request_status_changed\x18\x0b \x01(\x0b\x32\x46.org.couchers.api.conversations.MessageContentHostRequestStatusChangedH\x00\x12\\\n\x17group_chat_user_removed\x18\x0c \x01(\x0b\x32\x39.org.couchers.api.conversations.MessageContentUserRemovedH\x00\x42\t\n\x07\x63ontent\"J\n\x08MuteInfo\x12\r\n\x05muted\x18\x01 \x01(\x08\x12/\n\x0bmuted_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9e\x03\n\tGroupChat\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x17\n\x0fmember_user_ids\x18\x03 \x03(\x04\x12\x16\n\x0e\x61\x64min_user_ids\x18\x04 \x03(\x04\x12\x1a\n\x12only_admins_invite\x18\x05 \x01(\x08\x12\r\n\x05is_dm\x18\x06 \x01(\x08\x12+\n\x07\x63reated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14unseen_message_count\x18\x08 \x01(\r\x12\x1c\n\x14last_seen_message_id\x18\t \x01(\x04\x12?\n\x0elatest_message\x18\n \x01(\x0b\x32\'.org.couchers.api.conversations.Message\x12;\n\tmute_info\x18\x0b \x01(\x0b\x32(.org.couchers.api.conversations.MuteInfo\x12\x13\n\x0b\x63\x61n_message\x18\x0c \x01(\x08\x12\x13\n\x0bis_archived\x18\r \x01(\x08\"(\n\x0fGetGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"j\n\x11ListGroupChatsReq\x12\x17\n\x0flast_message_id\x18\x01 \x01(\x04\x12\x0e\n\x06number\x18\x02 \x01(\r\x12\x1a\n\ronly_archived\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x10\n\x0e_only_archived\"}\n\x11ListGroupChatsRes\x12>\n\x0bgroup_chats\x18\x01 \x03(\x0b\x32).org.couchers.api.conversations.GroupChat\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"*\n\rGetUpdatesReq\x12\x19\n\x11newest_message_id\x18\x01 \x01(\x04\"&\n\x13GetDirectMessageReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\"Y\n\x06Update\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\"Y\n\rGetUpdatesRes\x12\x37\n\x07updates\x18\x01 \x03(\x0b\x32&.org.couchers.api.conversations.Update\x12\x0f\n\x07no_more\x18\x02 \x01(\x08\"n\n\x17GetGroupChatMessagesReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0e\n\x06number\x18\x03 \x01(\r\x12\x13\n\x0bonly_unseen\x18\x04 \x01(\x08\"~\n\x17GetGroupChatMessagesRes\x12\x39\n\x08messages\x18\x01 \x03(\x0b\x32\'.org.couchers.api.conversations.Message\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08\"O\n\x18MarkLastSeenGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x1c\n\x14last_seen_message_id\x18\x02 \x01(\x04\"\x8d\x01\n\x10MuteGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x10\n\x06unmute\x18\x02 \x01(\x08H\x00\x12\x11\n\x07\x66orever\x18\x03 \x01(\x08H\x00\x12\x31\n\x0c\x66or_duration\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x42\n\n\x08\x64uration\"J\n\x1cSetGroupChatArchiveStatusReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"J\n\x1cSetGroupChatArchiveStatusRes\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x13\n\x0bis_archived\x18\x02 \x01(\x08\"]\n\x12\x43reateGroupChatReq\x12+\n\x05title\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x12recipient_user_ids\x18\x02 \x03(\x04\"\x8e\x01\n\x10\x45\x64itGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12+\n\x05title\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x12only_admins_invite\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\">\n\x14InviteToGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"?\n\x15MakeGroupChatAdminReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"@\n\x16RemoveGroupChatUserReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"A\n\x17RemoveGroupChatAdminReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\"5\n\x0eSendMessageReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"?\n\x14SendDirectMessageReq\x12\x19\n\x11recipient_user_id\x18\x01 \x01(\x04\x12\x0c\n\x04text\x18\x02 \x01(\t\"-\n\x14SendDirectMessageRes\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"*\n\x11LeaveGroupChatReq\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\"K\n\x11SearchMessagesReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0e\n\x06number\x18\x03 \x01(\r\"f\n\x13MessageSearchResult\x12\x15\n\rgroup_chat_id\x18\x01 \x01(\x04\x12\x38\n\x07message\x18\x02 \x01(\x0b\x32\'.org.couchers.api.conversations.Message\"\x83\x01\n\x11SearchMessagesRes\x12\x44\n\x07results\x18\x01 \x03(\x0b\x32\x33.org.couchers.api.conversations.MessageSearchResult\x12\x17\n\x0flast_message_id\x18\x02 \x01(\x04\x12\x0f\n\x07no_more\x18\x03 \x01(\x08*\xbe\x01\n\x11HostRequestStatus\x12\x1f\n\x1bHOST_REQUEST_STATUS_PENDING\x10\x00\x12 \n\x1cHOST_REQUEST_STATUS_ACCEPTED\x10\x01\x12 \n\x1cHOST_REQUEST_STATUS_REJECTED\x10\x02\x12!\n\x1dHOST_REQUEST_STATUS_CONFIRMED\x10\x03\x12!\n\x1dHOST_REQUEST_STATUS_CANCELLED\x10\x04\x32\xfb\x0f\n\rConversations\x12x\n\x0eListGroupChats\x12\x31.org.couchers.api.conversations.ListGroupChatsReq\x1a\x31.org.couchers.api.conversations.ListGroupChatsRes\"\x00\x12l\n\x0cGetGroupChat\x12/.org.couchers.api.conversations.GetGroupChatReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12t\n\x10GetDirectMessage\x12\x33.org.couchers.api.conversations.GetDirectMessageReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12l\n\nGetUpdates\x12-.org.couchers.api.conversations.GetUpdatesReq\x1a-.org.couchers.api.conversations.GetUpdatesRes\"\x00\x12\x8a\x01\n\x14GetGroupChatMessages\x12\x37.org.couchers.api.conversations.GetGroupChatMessagesReq\x1a\x37.org.couchers.api.conversations.GetGroupChatMessagesRes\"\x00\x12k\n\x15MarkLastSeenGroupChat\x12\x38.org.couchers.api.conversations.MarkLastSeenGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12[\n\rMuteGroupChat\x12\x30.org.couchers.api.conversations.MuteGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x99\x01\n\x19SetGroupChatArchiveStatus\x12<.org.couchers.api.conversations.SetGroupChatArchiveStatusReq\x1a<.org.couchers.api.conversations.SetGroupChatArchiveStatusRes\"\x00\x12r\n\x0f\x43reateGroupChat\x12\x32.org.couchers.api.conversations.CreateGroupChatReq\x1a).org.couchers.api.conversations.GroupChat\"\x00\x12[\n\rEditGroupChat\x12\x30.org.couchers.api.conversations.EditGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x63\n\x11InviteToGroupChat\x12\x34.org.couchers.api.conversations.InviteToGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x65\n\x12MakeGroupChatAdmin\x12\x35.org.couchers.api.conversations.MakeGroupChatAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\x13RemoveGroupChatUser\x12\x36.org.couchers.api.conversations.RemoveGroupChatUserReq\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x14RemoveGroupChatAdmin\x12\x37.org.couchers.api.conversations.RemoveGroupChatAdminReq\x1a\x16.google.protobuf.Empty\"\x00\x12W\n\x0bSendMessage\x12..org.couchers.api.conversations.SendMessageReq\x1a\x16.google.protobuf.Empty\"\x00\x12\x81\x01\n\x11SendDirectMessage\x12\x34.org.couchers.api.conversations.SendDirectMessageReq\x1a\x34.org.couchers.api.conversations.SendDirectMessageRes\"\x00\x12]\n\x0eLeaveGroupChat\x12\x31.org.couchers.api.conversations.LeaveGroupChatReq\x1a\x16.google.protobuf.Empty\"\x00\x12x\n\x0eSearchMessages\x12\x31.org.couchers.api.conversations.SearchMessagesReq\x1a\x31.org.couchers.api.conversations.SearchMessagesRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'conversations_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CONVERSATIONS']._loaded_options = None
  _globals['_CONVERSATIONS']._serialized_options = b'\210\265\030\003'
  _globals['_HOSTREQUESTSTATUS']._serialized_start=4217
  _globals['_HOSTREQUESTSTATUS']._serialized_end=4407
  _globals['_MESSAGECONTENTTEXT']._serialized_start=200
  _globals['_MESSAGECONTENTTEXT']._serialized_end=234
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_start=236
  _globals['_MESSAGECONTENTCHATCREATED']._serialized_end=263
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_start=265
  _globals['_MESSAGECONTENTCHATEDITED']._serialized_end=291
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_start=293
  _globals['_MESSAGECONTENTUSERINVITED']._serialized_end=344
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_start=346
  _globals['_MESSAGECONTENTUSERLEFT']._serialized_end=370
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_start=372
  _globals['_MESSAGECONTENTUSERMADEADMIN']._serialized_end=425
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_start=427
  _globals['_MESSAGECONTENTUSERREMOVEDADMIN']._serialized_end=483
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_start=485
  _globals['_MESSAGECONTENTUSERREMOVED']._serialized_end=536
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_start=538
  _globals['_MESSAGECONTENTHOSTREQUESTSTATUSCHANGED']._serialized_end=645
  _globals['_MESSAGE']._serialized_start=648
  _globals['_MESSAGE']._serialized_end=1533
  _globals['_MUTEINFO']._serialized_start=1535
  _globals['_MUTEINFO']._serialized_end=1609
  _globals['_GROUPCHAT']._serialized_start=1612
  _globals['_GROUPCHAT']._serialized_end=2026
  _globals['_GETGROUPCHATREQ']._serialized_start=2028
  _globals['_GETGROUPCHATREQ']._serialized_end=2068
  _globals['_LISTGROUPCHATSREQ']._serialized_start=2070
  _globals['_LISTGROUPCHATSREQ']._serialized_end=2176
  _globals['_LISTGROUPCHATSRES']._serialized_start=2178
  _globals['_LISTGROUPCHATSRES']._serialized_end=2303
  _globals['_GETUPDATESREQ']._serialized_start=2305
  _globals['_GETUPDATESREQ']._serialized_end=2347
  _globals['_GETDIRECTMESSAGEREQ']._serialized_start=2349
  _globals['_GETDIRECTMESSAGEREQ']._serialized_end=2387
  _globals['_UPDATE']._serialized_start=2389
  _globals['_UPDATE']._serialized_end=2478
  _globals['_GETUPDATESRES']._serialized_start=2480
  _globals['_GETUPDATESRES']._serialized_end=2569
  _globals['_GETGROUPCHATMESSAGESREQ']._serialized_start=2571
  _globals['_GETGROUPCHATMESSAGESREQ']._serialized_end=2681
  _globals['_GETGROUPCHATMESSAGESRES']._serialized_start=2683
  _globals['_GETGROUPCHATMESSAGESRES']._serialized_end=2809
  _globals['_MARKLASTSEENGROUPCHATREQ']._serialized_start=2811
  _globals['_MARKLASTSEENGROUPCHATREQ']._serialized_end=2890
  _globals['_MUTEGROUPCHATREQ']._serialized_start=2893
  _globals['_MUTEGROUPCHATREQ']._serialized_end=3034
  _globals['_SETGROUPCHATARCHIVESTATUSREQ']._serialized_start=3036
  _globals['_SETGROUPCHATARCHIVESTATUSREQ']._serialized_end=3110
  _globals['_SETGROUPCHATARCHIVESTATUSRES']._serialized_start=3112
  _globals['_SETGROUPCHATARCHIVESTATUSRES']._serialized_end=3186
  _globals['_CREATEGROUPCHATREQ']._serialized_start=3188
  _globals['_CREATEGROUPCHATREQ']._serialized_end=3281
  _globals['_EDITGROUPCHATREQ']._serialized_start=3284
  _globals['_EDITGROUPCHATREQ']._serialized_end=3426
  _globals['_INVITETOGROUPCHATREQ']._serialized_start=3428
  _globals['_INVITETOGROUPCHATREQ']._serialized_end=3490
  _globals['_MAKEGROUPCHATADMINREQ']._serialized_start=3492
  _globals['_MAKEGROUPCHATADMINREQ']._serialized_end=3555
  _globals['_REMOVEGROUPCHATUSERREQ']._serialized_start=3557
  _globals['_REMOVEGROUPCHATUSERREQ']._serialized_end=3621
  _globals['_REMOVEGROUPCHATADMINREQ']._serialized_start=3623
  _globals['_REMOVEGROUPCHATADMINREQ']._serialized_end=3688
  _globals['_SENDMESSAGEREQ']._serialized_start=3690
  _globals['_SENDMESSAGEREQ']._serialized_end=3743
  _globals['_SENDDIRECTMESSAGEREQ']._serialized_start=3745
  _globals['_SENDDIRECTMESSAGEREQ']._serialized_end=3808
  _globals['_SENDDIRECTMESSAGERES']._serialized_start=3810
  _globals['_SENDDIRECTMESSAGERES']._serialized_end=3855
  _globals['_LEAVEGROUPCHATREQ']._serialized_start=3857
  _globals['_LEAVEGROUPCHATREQ']._serialized_end=3899
  _globals['_SEARCHMESSAGESREQ']._serialized_start=3901
  _globals['_SEARCHMESSAGESREQ']._serialized_end=3976
  _globals['_MESSAGESEARCHRESULT']._serialized_start=3978
  _globals['_MESSAGESEARCHRESULT']._serialized_end=4080
  _globals['_SEARCHMESSAGESRES']._serialized_start=4083
  _globals['_SEARCHMESSAGESRES']._serialized_end=4214
  _globals['_CONVERSATIONS']._serialized_start=4410
  _globals['_CONVERSATIONS']._serialized_end=6453
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2020 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

import builtins
import collections.abc
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HttpBody(google.protobuf.message.Message):
    """Message that represents an arbitrary HTTP body. It should only be used for
    payload formats that can't be represented as JSON, such as raw binary or
    an HTML page.


    This message can be used both in streaming and non-streaming API methods in
    the request as well as the response.

    It can be used as a top-level request field, which is convenient if one
    wants to extract parameters from either the URL or HTTP template into the
    request fields and also want access to the raw HTTP body.

    Example:

        message GetResourceRequest {
          // A unique request id.
          string request_id = 1;

          // The raw HTTP body is bound to this field.
          google.api.HttpBody http_body = 2;
        }

        service ResourceService {
          rpc GetResource(GetResourceRequest) returns (google.api.HttpBody);
          rpc UpdateResource(google.api.HttpBody) returns
          (google.protobuf.Empty);
        }

    Example with streaming methods:

        service CaldavService {
          rpc GetCalendar(stream google.api.HttpBody)
            returns (stream google.api.HttpBody);
          rpc UpdateCalendar(stream google.api.HttpBody)
            returns (stream google.api.HttpBody);
        }

    Use of this type only changes how the request and response bodies are
    handled, all other features will continue to work unchanged.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    EXTENSIONS_FIELD_NUMBER: builtins.int
    content_type: builtins.str
    """The HTTP Content-Type header value specifying the content type of the body."""
    data: builtins.bytes
    """The HTTP request/response body as raw binary."""
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.any_pb2.Any]:
        """Application specific response metadata. Must be set in the first response
        for streaming APIs.
        """

    def __init__(
        self,
        *,
        content_type: builtins.str | None = ...,
        data: builtins.bytes | None = ...,
        extensions: collections.abc.Iterable[google.protobuf.any_pb2.Any] | None = ...,
    ) -> None: ...
    _ClearFieldArgType: typing_extensions.TypeAlias = typing.Literal["content_type", b"content_type", "data", b"data", "extensions", b"extensions"]
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

Global___HttpBody: typing_extensions.TypeAlias = HttpBody



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import search_pb2 as search__pb2


class SearchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Search = channel.unary_unary(
                '/org.couchers.api.search.Search/Search',
                request_serializer=search__pb2.SearchReq.SerializeToString,
                response_deserializer=search__pb2.SearchRes.FromString,
                )
        self.UserSearch = channel.unary_unary(
                '/org.couchers.api.search.Search/UserSearch',
                request_serializer=search__pb2.UserSearchReq.SerializeToString,
                response_deserializer=search__pb2.UserSearchRes.FromString,
                )
        self.UserSearchV2 = channel.unary_unary(
                '/org.couchers.api.search.Search/UserSearchV2',
                request_serializer=search__pb2.UserSearchReq.SerializeToString,
                response_deserializer=search__pb2.UserSearchV2Res.FromString,
                )
        self.EventSearch = channel.unary_unary(
                '/org.couchers.api.search.Search/EventSearch',
                request_serializer=search__pb2.EventSearchReq.SerializeToString,
                response_deserializer=search__pb2.EventSearchRes.FromString,
                )


class SearchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Search(self, request, context):
        """Search all content
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserSearch(self, request, context):
        """Search for users in particular with extra filters, e.g. hosts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UserSearchV2(self, request, context):
        """Search for users in particular with extra filters, e.g. hosts
        only returns used fields
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EventSearch(self, request, context):
        """Search for events in particular with extra filters
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Search': grpc.unary_unary_rpc_method_handler(
                    servicer.Search,
                    request_deserializer=search__pb2.SearchReq.FromString,
                    response_serializer=search__pb2.SearchRes.SerializeToString,
            ),
            'UserSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.UserSearch,
                    request_deserializer=search__pb2.UserSearchReq.FromString,
                    response_serializer=search__pb2.UserSearchRes.SerializeToString,
            ),
            'UserSearchV2': grpc.unary_unary_rpc_method_handler(
                    servicer.UserSearchV2,
                    request_deserializer=search__pb2.UserSearchReq.FromString,
                    response_serializer=search__pb2.UserSearchV2Res.SerializeToString,
            ),
            'EventSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.EventSearch,
                    request_deserializer=search__pb2.EventSearchReq.FromString,
                    response_serializer=search__pb2.EventSearchRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.search.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Search(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.search.Search/Search',
            search__pb2.SearchReq.SerializeToString,
            search__pb2.SearchRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.search.Search/UserSearch',
            search__pb2.UserSearchReq.SerializeToString,
            search__pb2.UserSearchRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UserSearchV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.search.Search/UserSearchV2',
            search__pb2.UserSearchReq.SerializeToString,
            search__pb2.UserSearchV2Res.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EventSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.search.Search/EventSearch',
            search__pb2.EventSearchReq.SerializeToString,
            search__pb2.EventSearchRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.api.httpbody_pb2
import grpc
import grpc.aio
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class IrisStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Webhook: grpc.UnaryUnaryMultiCallable[google.api.httpbody_pb2.HttpBody, google.api.httpbody_pb2.HttpBody]

class IrisServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Webhook(
        self,
        request: google.api.httpbody_pb2.HttpBody,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.api.httpbody_pb2.HttpBody: ...

def add_IrisServicer_to_server(servicer: IrisServicer, server: grpc.Server) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import blocking_pb2 as blocking__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BlockingStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BlockUser = channel.unary_unary(
                '/org.couchers.blocking.Blocking/BlockUser',
                request_serializer=blocking__pb2.BlockUserReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UnblockUser = channel.unary_unary(
                '/org.couchers.blocking.Blocking/UnblockUser',
                request_serializer=blocking__pb2.UnblockUserReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetBlockedUsers = channel.unary_unary(
                '/org.couchers.blocking.Blocking/GetBlockedUsers',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=blocking__pb2.GetBlockedUsersRes.FromString,
                )


class BlockingServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BlockUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnblockUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockedUsers(self, request, context):
        """Returns all users blocked by a given account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BlockingServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BlockUser': grpc.unary_unary_rpc_method_handler(
                    servicer.BlockUser,
                    request_deserializer=blocking__pb2.BlockUserReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UnblockUser': grpc.unary_unary_rpc_method_handler(
                    servicer.UnblockUser,
                    request_deserializer=blocking__pb2.UnblockUserReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetBlockedUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockedUsers,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=blocking__pb2.GetBlockedUsersRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.blocking.Blocking', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Blocking(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BlockUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.blocking.Blocking/BlockUser',
            blocking__pb2.BlockUserReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnblockUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.blocking.Blocking/UnblockUser',
            blocking__pb2.UnblockUserReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockedUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.blocking.Blocking/GetBlockedUsers',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            blocking__pb2.GetBlockedUsersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import references_pb2
import typing


GRPC_GENERATED_VERSION: str
GRPC_VERSION: str

class ReferencesStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    ListReferences: grpc.UnaryUnaryMultiCallable[references_pb2.ListReferencesReq, references_pb2.ListReferencesRes]
    """Returns a paginated list of references satisfying some filtering criterion"""
    WriteFriendReference: grpc.UnaryUnaryMultiCallable[references_pb2.WriteFriendReferenceReq, references_pb2.Reference]
    """Write a reference for your friend. Raises INVALID_ARGUMENT if you
    try to write for yourself, or NOT_FOUND if the user doesn't exist.
    Raises FAILED_PRECONDITION if you try to write a reference for someone you already wrote a friend reference for.
    """
    WriteHostRequestReference: grpc.UnaryUnaryMultiCallable[references_pb2.WriteHostRequestReferenceReq, references_pb2.Reference]
    """Write a reference for someone after having hosted/surfed with them. Raises NOT_FOUND if the request doesn't
    exist.
    """
    HostRequestIndicateDidntMeetup: grpc.UnaryUnaryMultiCallable[references_pb2.HostRequestIndicateDidntMeetupReq, google.protobuf.empty_pb2.Empty]
    """Indicate that the user didn't meet up"""
    AvailableWriteReferences: grpc.UnaryUnaryMultiCallable[references_pb2.AvailableWriteReferencesReq, references_pb2.AvailableWriteReferencesRes]
    """Return the reference types that is, at the moment, possible to write about a user."""
    ListPendingReferencesToWrite: grpc.UnaryUnaryMultiCallable[google.protobuf.empty_pb2.Empty, references_pb2.ListPendingReferencesToWriteRes]
    """Returns a list of references that you should write about others, e.g. after surfing or hosting"""
    GetHostRequestReferenceStatus: grpc.UnaryUnaryMultiCallable[references_pb2.GetHostRequestReferenceStatusReq, references_pb2.GetHostRequestReferenceStatusRes]
    """Returns status for whether the current user can write a host-request reference for the given request id"""

class ReferencesServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def ListReferences(
        self,
        request: references_pb2.ListReferencesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.ListReferencesRes:
        """Returns a paginated list of references satisfying some filtering criterion"""

    @abc.abstractmethod
    def WriteFriendReference(
        self,
        request: references_pb2.WriteFriendReferenceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.Reference:
        """Write a reference for your friend. Raises INVALID_ARGUMENT if you
        try to write for yourself, or NOT_FOUND if the user doesn't exist.
        Raises FAILED_PRECONDITION if you try to write a reference for someone you already wrote a friend reference for.
        """

    @abc.abstractmethod
    def WriteHostRequestReference(
        self,
        request: references_pb2.WriteHostRequestReferenceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.Reference:
        """Write a reference for someone after having hosted/surfed with them. Raises NOT_FOUND if the request doesn't
        exist.
        """

    @abc.abstractmethod
    def HostRequestIndicateDidntMeetup(
        self,
        request: references_pb2.HostRequestIndicateDidntMeetupReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> google.protobuf.empty_pb2.Empty:
        """Indicate that the user didn't meet up"""

    @abc.abstractmethod
    def AvailableWriteReferences(
        self,
        request: references_pb2.AvailableWriteReferencesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.AvailableWriteReferencesRes:
        """Return the reference types that is, at the moment, possible to write about a user."""

    @abc.abstractmethod
    def ListPendingReferencesToWrite(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.ListPendingReferencesToWriteRes:
        """Returns a list of references that you should write about others, e.g. after surfing or hosting"""

    @abc.abstractmethod
    def GetHostRequestReferenceStatus(
        self,
        request: references_pb2.GetHostRequestReferenceStatusReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> references_pb2.GetHostRequestReferenceStatusRes:
        """Returns status for whether the current user can write a host-request reference for the given request id"""

def add_ReferencesServicer_to_server(servicer: ReferencesServicer, server: grpc.Server) -> None: ...
